==> ginkgocadx_2.8.0.4602.orig.tar.gz: ginkgocadx-2.8.0.4602/src/cadxcore/main/gui/mainwindow/ventanaprincipal.h <==
/*
 *  
 *  $Id: ventanaprincipal.h 4502 2012-01-09 12:19:39Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once

#include <wx/event.h>
#include <wx/aui/aui.h>
#include "ventanaprincipalbase.h"

#include <api/globals.h>
#include <api/api.h>
#include <api/icontroladormodulo.h>
#include <api/iherramienta.h>
#include <api/icontroladoreventos.h>
#include <main/controllers/controladorvistas.h>
#include <main/controllers/controladorextensiones.h>

namespace GNC {
	namespace GUI {
		class PanelGrid;
		class PanelHistorial2;
	}
	class Entorno;
}
class wxHtmlEasyPrinting;
class wxWindowDisabler;
class wxScrolledWindow;
class wxPrintData;

const wxEventType wxEVT_PROGRESO = wxNewEventType();

extern const wxEventType wxEVT_PROGRESO;

//DEFINE_EVENT_TYPE(wxEVT_PROGRESO)

/*BEGIN_DECLARE_EVENT_TYPES()
	DECLARE_EVENT_TYPE( wxEVT_PROGRESO, wxNewEventType() )
END_DECLARE_EVENT_TYPES()
*/
class EventoProgreso : public wxEvent
{
public:

	typedef enum
	{
		ComandoIniciado = 0,
		ComandoEjecutando,
		ComandoFinalizado,
		Invalido
	} TipoProgreso;

	EventoProgreso(TipoProgreso tipo = Invalido, long threadId = 0);

	EventoProgreso(const EventoProgreso& event);

	~EventoProgreso();

	long GetTipo() const
	{
		return m_Tipo;
	}

	long GetThreadId() const
	{
		return m_ThreadId;
	}

	virtual wxEvent *Clone() const;

protected:
	TipoProgreso m_Tipo;
	long         m_ThreadId;

private:
    DECLARE_DYNAMIC_CLASS_NO_ASSIGN(EventoProgreso)
};

typedef void (wxEvtHandler::*EventoProgresoFunction)(EventoProgreso&);

#define EventoProgresoFunctionHandler(func) \
    (wxObjectEventFunction)(wxEventFunction)wxStaticCastEvent(EventoProgresoFunction, &func)

#define EVT_PROGRESO(func) \
    wx__DECLARE_EVT0(wxEVT_PROGRESO, EventoProgresoFunctionHandler(func))


class EXTAPI VentanaPrincipal : public VentanaPrincipalBase, public GNC::GCS::IObservadorExtensiones, public GNC::GCS::IObservadorVistas, public GNC::GCS::IObservador {
public:

	/* Constructor */
	VentanaPrincipal(const wxString& title);

	/* Destructor */
	~VentanaPrincipal();

	/*cambia de pestaña*/
	void ForzarCambioVista(GNC::GCS::IVista* pVista);

protected:

//region "Helpers"

	/* Carga los iconos estaticos */
	void ConstruirBarraHerramientasEstatica();

public:
	void RefrescarMenus();
	void CargarHistorial();

//endregion

//region "Eventos de actualizaciones"

protected:
	std::string m_VersionNueva; // Cadena con la version nueva para mostrar en mensajes y notificaciones (Ej: "1.5.0 beta")
	std::string m_VersionCheck; // Cadena con la version nueva con secuencia build para fichar version y poder ignorarla. (Ej: "1.5.0.0", que podria ser 1.5.0 beta | "1.5.0.1" que podria ser 1.5.0 final)
	bool        m_VersionChecked;
public:
	void ComprobarActualizaciones();

	virtual void OnDoNotWarnAgainClicked( wxCommandEvent& event );
	virtual void OnVersionNotifierClose( wxCommandEvent& event );

//endregion

//region "Eventos de menu"
public:
	/* Evento de cerrar aplicacion (evitable) */
	void OnWindowClose(wxCloseEvent& event);

	/* Evento de salir de la aplicacion */
	virtual void OnSalir(wxCommandEvent& event);

	virtual void OnDropDownAcquire(wxAuiToolBarEvent& event);

	/* Evento de lanzamiento de ventana "Acerca De" */
	virtual void OnAcercaDe(wxCommandEvent& event);

	/* Evento de lanzamiento de ventana "Online Help" */
	virtual void OnOnlineHelp(wxCommandEvent& event);

	/* Evento de lanzamiento de ventana "Online support" */
	virtual void OnOnlineSupport(wxCommandEvent& event);
	
	/* Launch event window "Extensions Support" */
	virtual void OnExtensionsSupport(wxCommandEvent& event);

	/* Evento de lanzamiento de la comprobacion de actualizaciones */
	virtual void OnCheckForUpdates(wxCommandEvent& event);

	/*startup page*/
	void OnShowStartupPage(wxCommandEvent& event);
	void ShowStartupPage();

	/* Evento de apertura de estudio */
	virtual void OnAdquirir(wxCommandEvent& event);

	/*Evento de apertura de fichero*/
	virtual void OnAbrirFichero(wxCommandEvent& event);

	/*Evento de open disc*/
	virtual void OnOpenRemovableUnit(wxCommandEvent& event);


	/*Evento de apertura de directorio*/
	virtual void OnAbrirDirectorio(wxCommandEvent& event);

	#ifdef __WXMAC__
	void MacOpenFile(const wxString &fileName);
	#endif

	/* Evento de importacion de estudio */
	virtual void OnImportar(wxCommandEvent& event);

	/* Evento de guardado de un estudio */
	virtual void OnGuardar(wxCommandEvent& event);

	/* Evento de exportado de un estudio */
	virtual void OnExportar(wxCommandEvent& event);

	virtual void OnDicomDirExport(wxCommandEvent& event);

	/* Evento de exportado de un subir al pacs */
	virtual void OnSubirPACS(wxCommandEvent& event);

	/* Evento de actualizacion de elemento de menu de guardar */
	virtual void OnUpdateGuardar(wxUpdateUIEvent& event);

	/* Evento de actualizacion de elemento de menu de subir al pacs */
	virtual void OnUpdateExportar(wxUpdateUIEvent& event);

	/* Evento de actualizacion de elemento de menu de exportar */
	virtual void OnUpdateSubirPACS(wxUpdateUIEvent& event);

	/* Evento de configuracion */
	virtual void OnConfiguracion(wxCommandEvent& event);

	/*Evento de ventana de control de envio HL7*/
	virtual void OnMensajesHL7(wxCommandEvent& event);

	/*Evento de ventana de control de registros (Logs)*/
	virtual void OnControlLogs(wxCommandEvent& event);

	/* Evento de aplicacion de filtro sobre vista */
	virtual void OnAplicarHerramienta(wxCommandEvent& event);
	virtual void OnUpdateUIHerramienta(wxUpdateUIEvent& event);

	/* Evento de aplicacion de filtro sobre vista */
	virtual void OnAplicarFiltro(wxCommandEvent& event);

	/* Eventos de teclado */
	virtual void OnKeyDown(wxKeyEvent& event);

	/*menu sobre pestanias*/
	void OnMenuCerrarTabClick(wxCommandEvent& event);

	void OnMenuCerrarTodoExceptoActiva(wxCommandEvent& event);

	void OnMenuCerrarTodosTabsClick(wxCommandEvent& event);

	//devuelve bool si ha cerrado todos
	bool CerrarTodosLosTabsYPanelGrids();

	//closes all undocked windows
	bool ClosesAllUndocked();

	void OnMenuCerrarTabUpdateUI(wxUpdateUIEvent& event);

	void OnMenuCerrarTodosTabsUpdateUI(wxUpdateUIEvent& event);

	void OnMenuPrimerPlanoPestaniaActiva(wxCommandEvent& event);

	/*Eventos de impresion*/
	void OnMenuImprimir(wxCommandEvent& event);
	void OnMenuImprimirUpdateUI(wxUpdateUIEvent& event);

	/*Eventos de vista*/
	void OnPantallaCompleta(wxCommandEvent& event);

	/*reorganizacion de pestañas*/

	//toggle entre enc
	void EncajarDesencajar(GNC::GCS::IVista* pVista);
	void OnMosaicoHorizontal(wxCommandEvent& event);
	void OnMosaicoVertical(wxCommandEvent& event);
	void OnMosaicoRestaurar(wxCommandEvent& event);
	void OnMosaicoGrid2Col(wxCommandEvent& event);
	void OnMosaicoGrid3Col(wxCommandEvent& event);
	//helper
	void AddToGrid(int numColumnas);
	void ReplegarPestanias();

//endregion

public:
//region "Eventos de ventana"

	/*evento que se ejecuta cuando se activa la app sirve para parsear los parametros*/
	void OnInicioAplicacion(wxCommandEvent& event);
	void EjecutarParametro(const wxString cadena, bool doLogin = false);
	/* Evento absurdo pero necesario para evitar efectos de "flickering" */

	virtual void OnVentanaPrincipalEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnBarraHerramientasEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnPanelHerramientasEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnPanelHerramientasOpcionesEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnPanelActualizacionEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnPanelActualizacionInternoEraseBackground( wxEraseEvent& event )
	{
		event.Skip(true);
	}
	virtual void OnPanelCentralEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnNoteBookEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}

	/* Cambio de tamaño de la ventana */
	void OnSize(wxSizeEvent& event);

//endregion

//region "Eventos del control de pestañas"
	void OnPanelClose(wxAuiManagerEvent& event);
public:
	bool CerrarVista(GNC::GCS::IVista* pVista);
	bool CerrarVista(wxWindow* window);
	void DestruirPanelGrid(GNC::GUI::PanelGrid* pPanelGrid);
	void PasarAPrimerPlano(wxWindow* window);
protected:
	void OnNotebookPageChanging(wxAuiNotebookEvent& event);
	void OnNotebookPageChanged(wxAuiNotebookEvent& event);
	void OnNotebookPageClose(wxAuiNotebookEvent&   event);
	void OnNotebookCambiarTab(wxAuiNotebookEvent&  event);
	void OnNotebookMenuTab(wxAuiNotebookEvent&     event);
	void OnNotebookFocus(wxChildFocusEvent&        event);


public:
	void DestruirPanelVista(wxWindow* panel);

protected:
	void CerrarNotebookPage(wxWindow* panel);

//endregion

//region "eventos ginkgo"
protected:
	void ProcesarEvento(GNC::GCS::Eventos::IEvento *evt);
//endregion

//endregion


//region "Puntos de entrada al hilo principal de la interfaz para controlar comandos"

	void OnComando(EventoProgreso& event);

//endregion

//region "Punto de entrada al controlador de eventos"
	void OnEvento(wxCommandEvent& event);
//endregion

public:
	/* Inserta una ventana en el notebook o grid  */
	void InsertarVentana(wxWindow* pVista);

	/* Elimina una vista del notebook o grid */
	void EliminarVentana(wxWindow* pVentana);

//region "Getters y Setters de elementos de la interfaz"

public:
	AUI_NAMESPACE wxAuiNotebook* GetAUINoteBook();
	GNC::GUI::PanelHistorial2* GetPanelHistorial();

public:

//region "Realización de la interfaz IObservadorExtensiones"

	virtual void OnModuloCargado(GNC::GCS::IControladorModulo*     pCM);
	virtual void OnModuloDescargado(GNC::GCS::IControladorModulo*  pCM);
	virtual void OnModuloActivado(GNC::GCS::IControladorModulo*    pCM);
	virtual void OnModuloDesactivado(GNC::GCS::IControladorModulo* pCM);

//endregion

//region "Realización de la interfaz IObservadorVistas"

	virtual void OnVistaActivada(GNC::GCS::IVista* pVista);

//endregion

	wxAuiManager          m_mgr;
	wxAuiNotebook*        m_pNoteBook;
	wxPanel*              m_pMosaicPanel;
	//javi prueba del grid
	wxScrolledWindow*     m_pGridPanel;


//region "helpers"
	void SuperFreeze();
	void SuperThaw();
	void PauseSuperFreeze();
	void ContSuperFreeze();

protected:
	int m_SuperFreezeCount;
	wxWindowDisabler* disabler; // Implementación similar a freeze/thaw pero a nivel de eventos y no respecto a responsabilidad de widgets.

//endregion


//region "login e inicializacion"
public:
	void Login();
	void MostrarVentana();

//endregion

protected:
	GNC::GUI::PanelHistorial2*  m_pHistorial;

	wxMenu*                     m_pMenuModulo;
	AUI_NAMESPACE wxAuiToolBar* m_pBarraComun;

	/*
	ssize_t                     m_NumBackgroundRunning;
	ssize_t                     m_NumBackgroundCount;
	bool                        m_Canceled;
	wxCriticalSection           m_BackgroundCriticalSection;

	ssize_t                     m_NumComandosRunning;
	ssize_t                     m_NumComandosCount;
	wxCriticalSection           m_ComandosCriticalSection;
	*/

	// Mapa entre id_de_wxwidgets => id de filtro para resolver ids de filtros desde el manejador de evento.
	std::map<unsigned long, unsigned long> m_Mapafiltros;

	// Variable que controla la coherencia de confirmación entre cerrado de la aplicacion y cerrado de tabs para
	// no informar varias veces de lo mismo.
	bool                  m_TratandoDeCerrar;

	wxMenuBar*            m_pMenuBar;
	wxPrintData*	       m_pPrintData;

	DECLARE_EVENT_TABLE()
	friend class GNC::GCS::ControladorVistas;
	bool                  m_Iniciada;
};

/* Acciones de Menus */
enum {
	ID_Inicio_Aplicacion = 99
};

==> ginkgocadx_2.12.0.4889.orig.tar.gz: ginkgocadx-2.12.0.4889/src/cadxcore/main/gui/mainwindow/ventanaprincipal.h <==
/*
 *  
 *  $Id: ventanaprincipal.h 4571 2012-01-19 09:08:09Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once

#include <wx/event.h>
#include <wx/aui/aui.h>
#include "ventanaprincipalbase.h"

#include <api/globals.h>
#include <api/api.h>
#include <api/icontroladormodulo.h>
#include <api/iherramienta.h>
#include <api/icontroladoreventos.h>
#include <main/controllers/controladorvistas.h>
#include <main/controllers/controladorextensiones.h>

namespace GNC {
	namespace GUI {
		class PanelGrid;
		class PanelHistorial2;
	}
	class Entorno;
}
class wxHtmlEasyPrinting;
class wxWindowDisabler;
class wxScrolledWindow;
class wxPrintData;

const wxEventType wxEVT_PROGRESO = wxNewEventType();

extern const wxEventType wxEVT_PROGRESO;

//DEFINE_EVENT_TYPE(wxEVT_PROGRESO)

/*BEGIN_DECLARE_EVENT_TYPES()
	DECLARE_EVENT_TYPE( wxEVT_PROGRESO, wxNewEventType() )
END_DECLARE_EVENT_TYPES()
*/
class EventoProgreso : public wxEvent
{
public:

	typedef enum
	{
		ComandoIniciado = 0,
		ComandoEjecutando,
		ComandoFinalizado,
		Invalido
	} TipoProgreso;

	EventoProgreso(TipoProgreso tipo = Invalido, long threadId = 0);

	EventoProgreso(const EventoProgreso& event);

	~EventoProgreso();

	long GetTipo() const
	{
		return m_Tipo;
	}

	long GetThreadId() const
	{
		return m_ThreadId;
	}

	virtual wxEvent *Clone() const;

protected:
	TipoProgreso m_Tipo;
	long         m_ThreadId;

private:
    DECLARE_DYNAMIC_CLASS_NO_ASSIGN(EventoProgreso)
};

typedef void (wxEvtHandler::*EventoProgresoFunction)(EventoProgreso&);

#define EventoProgresoFunctionHandler(func) \
    (wxObjectEventFunction)(wxEventFunction)wxStaticCastEvent(EventoProgresoFunction, &func)

#define EVT_PROGRESO(func) \
    wx__DECLARE_EVT0(wxEVT_PROGRESO, EventoProgresoFunctionHandler(func))


class EXTAPI VentanaPrincipal : public VentanaPrincipalBase, public GNC::GCS::IObservadorExtensiones, public GNC::GCS::IObservadorVistas, public GNC::GCS::IObservador {
public:

	/* Constructor */
	VentanaPrincipal(const wxString& title);

	/* Destructor */
	~VentanaPrincipal();

	/*cambia de pestaña*/
	void ForzarCambioVista(GNC::GCS::IVista* pVista);

protected:

//region "Helpers"

public:
	void RefrescarMenus();
	void CargarHistorial();

//endregion

//region "Eventos de actualizaciones"

protected:
	std::string m_VersionNueva; // Cadena con la version nueva para mostrar en mensajes y notificaciones (Ej: "1.5.0 beta")
	std::string m_VersionCheck; // Cadena con la version nueva con secuencia build para fichar version y poder ignorarla. (Ej: "1.5.0.0", que podria ser 1.5.0 beta | "1.5.0.1" que podria ser 1.5.0 final)
	bool        m_VersionChecked;
public:
	void ComprobarActualizaciones();

	virtual void OnDoNotWarnAgainClicked( wxCommandEvent& event );
	virtual void OnVersionNotifierClose( wxCommandEvent& event );

//endregion

//region "Eventos de menu"
public:
	/* Evento de cerrar aplicacion (evitable) */
	void OnWindowClose(wxCloseEvent& event);

	/* Evento de salir de la aplicacion */
	virtual void OnSalir(wxCommandEvent& event);

	virtual void OnDropDownAcquire(wxAuiToolBarEvent& event);
	virtual void OnDropDownPacs(wxAuiToolBarEvent& event);

	/* Evento de lanzamiento de ventana "Acerca De" */
	virtual void OnAcercaDe(wxCommandEvent& event);

	/* Evento de lanzamiento de ventana "Online Help" */
	virtual void OnOnlineHelp(wxCommandEvent& event);

	/* Evento de lanzamiento de ventana "Online support" */
	virtual void OnOnlineSupport(wxCommandEvent& event);
	
	/* Launch event window "Extensions Support" */
	virtual void OnExtensionsSupport(wxCommandEvent& event);

	/* Evento de lanzamiento de la comprobacion de actualizaciones */
	virtual void OnCheckForUpdates(wxCommandEvent& event);

	/*startup page*/
	void OnShowStartupPage(wxCommandEvent& event);
	void ShowStartupPage();

	/* Evento de apertura de estudio */
	virtual void OnPACSAcquisition(wxCommandEvent& event);

	/*Evento de apertura de fichero*/
	virtual void OnAbrirFichero(wxCommandEvent& event);

	/*Evento de open disc*/
	virtual void OnOpenRemovableUnit(wxCommandEvent& event);


	/*Evento de apertura de directorio*/
	virtual void OnAbrirDirectorio(wxCommandEvent& event);

	#ifdef __WXMAC__
	void MacOpenFile(const wxString &fileName);
	#endif

	/* Evento de importacion de estudio */
	virtual void OnImportar(wxCommandEvent& event);

	/* Evento de guardado de un estudio */
	virtual void OnGuardar(wxCommandEvent& event);

	/* Evento de exportado de un estudio */
	virtual void OnExportar(wxCommandEvent& event);

	virtual void OnDicomDirExport(wxCommandEvent& event);

	/* Evento de exportado de un subir al pacs */
	virtual void OnSubirPACS(wxCommandEvent& event);

	/* Evento de actualizacion de elemento de menu de guardar */
	virtual void OnUpdateGuardar(wxUpdateUIEvent& event);

	/* Evento de actualizacion de elemento de menu de subir al pacs */
	virtual void OnUpdateExportar(wxUpdateUIEvent& event);

	/* Evento de actualizacion de elemento de menu de exportar */
	virtual void OnUpdateSubirPACS(wxUpdateUIEvent& event);

	/* Evento de configuracion */
	virtual void OnConfiguracion(wxCommandEvent& event);

	/*Evento de ventana de control de envio HL7*/
	virtual void OnMensajesHL7(wxCommandEvent& event);

	/*Evento de ventana de control de registros (Logs)*/
	virtual void OnControlLogs(wxCommandEvent& event);

	/* Evento de aplicacion de herramientas*/
	virtual void OnAplicarHerramienta(wxCommandEvent& event);
	virtual void OnUpdateUIHerramienta(wxUpdateUIEvent& event);
	virtual int InsertToolsFromFamily(wxMenu* pParent, GNC::GCS::IHerramienta::TFamiliasHerramientas family);

	/* Eventos de teclado */
	virtual void OnKeyDown(wxKeyEvent& event);

	/*menu sobre pestanias*/
	void OnMenuCerrarTabClick(wxCommandEvent& event);

	void OnMenuCerrarTodoExceptoActiva(wxCommandEvent& event);

	void OnMenuCerrarTodosTabsClick(wxCommandEvent& event);

	//devuelve bool si ha cerrado todos
	bool CerrarTodosLosTabsYPanelGrids();

	//closes all undocked windows
	bool ClosesAllUndocked();

	void OnMenuCerrarTabUpdateUI(wxUpdateUIEvent& event);

	void OnMenuCerrarTodosTabsUpdateUI(wxUpdateUIEvent& event);

	void OnMenuPrimerPlanoPestaniaActiva(wxCommandEvent& event);

	/*Eventos de impresion*/
	void OnMenuImprimir(wxCommandEvent& event);
	void OnMenuImprimirUpdateUI(wxUpdateUIEvent& event);

	/*Eventos de vista*/
	void OnPantallaCompleta(wxCommandEvent& event);

	/*reorganizacion de pestañas*/

	//toggle entre enc
	void EncajarDesencajar(GNC::GCS::IVista* pVista);
	void OnMosaicoHorizontal(wxCommandEvent& event);
	void OnMosaicoVertical(wxCommandEvent& event);
	void OnMosaicoRestaurar(wxCommandEvent& event);
	void OnMosaicoGrid2Col(wxCommandEvent& event);
	void OnMosaicoGrid3Col(wxCommandEvent& event);
	//helper
	void AddToGrid(int numColumnas);
	void ReplegarPestanias();

//endregion

public:
//region "Eventos de ventana"

	/*evento que se ejecuta cuando se activa la app sirve para parsear los parametros*/
	void OnInicioAplicacion(wxCommandEvent& event);
	void EjecutarParametro(const wxString cadena, bool doLogin = false);
	/* Evento absurdo pero necesario para evitar efectos de "flickering" */

	virtual void OnVentanaPrincipalEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnBarraHerramientasEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnPanelHerramientasEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnPanelHerramientasOpcionesEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnPanelActualizacionEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnPanelActualizacionInternoEraseBackground( wxEraseEvent& event )
	{
		event.Skip(true);
	}
	virtual void OnPanelCentralEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}
	virtual void OnNoteBookEraseBackground( wxEraseEvent& event )
	{
		event.Skip(false);
	}

	/* Cambio de tamaño de la ventana */
	void OnSize(wxSizeEvent& event);

//endregion

//region "Eventos del control de pestañas"
	void OnPanelClose(wxAuiManagerEvent& event);
public:
	bool CerrarVista(GNC::GCS::IVista* pVista);
	bool CerrarVista(wxWindow* window);
	void DestruirPanelGrid(GNC::GUI::PanelGrid* pPanelGrid);
	void PasarAPrimerPlano(wxWindow* window);
protected:
	void OnNotebookPageChanging(wxAuiNotebookEvent& event);
	void OnNotebookPageChanged(wxAuiNotebookEvent& event);
	void OnNotebookPageClose(wxAuiNotebookEvent&   event);
	void OnNotebookCambiarTab(wxAuiNotebookEvent&  event);
	void OnNotebookMenuTab(wxAuiNotebookEvent&     event);
	void OnNotebookFocus(wxChildFocusEvent&        event);


public:
	void DestruirPanelVista(wxWindow* panel);

protected:
	void CerrarNotebookPage(wxWindow* panel);

//endregion

//region "eventos ginkgo"
protected:
	void ProcesarEvento(GNC::GCS::Eventos::IEvento *evt);
//endregion

//endregion


//region "Puntos de entrada al hilo principal de la interfaz para controlar comandos"

	void OnComando(EventoProgreso& event);

//endregion

//region "Punto de entrada al controlador de eventos"
	void OnEvento(wxCommandEvent& event);
//endregion

public:
	/* Inserta una ventana en el notebook o grid  */
	void InsertarVentana(wxWindow* pVista);

	/* Elimina una vista del notebook o grid */
	void EliminarVentana(wxWindow* pVentana);

//region "Getters y Setters de elementos de la interfaz"

public:
	AUI_NAMESPACE wxAuiNotebook* GetAUINoteBook();
	GNC::GUI::PanelHistorial2* GetPanelHistorial();

public:

//region "Realización de la interfaz IObservadorExtensiones"

	virtual void OnModuloCargado(GNC::GCS::IControladorModulo*     pCM);
	virtual void OnModuloDescargado(GNC::GCS::IControladorModulo*  pCM);
	virtual void OnModuloActivado(GNC::GCS::IControladorModulo*    pCM);
	virtual void OnModuloDesactivado(GNC::GCS::IControladorModulo* pCM);

//endregion

//region "Realización de la interfaz IObservadorVistas"

	virtual void OnVistaActivada(GNC::GCS::IVista* pVista);

//endregion

	wxAuiManager          m_mgr;
	wxAuiNotebook*        m_pNoteBook;
	wxPanel*              m_pMosaicPanel;
	//javi prueba del grid
	wxScrolledWindow*     m_pGridPanel;


//region "helpers"
	void SuperFreeze();
	void SuperThaw();
	void PauseSuperFreeze();
	void ContSuperFreeze();

protected:
	int m_SuperFreezeCount;
	wxWindowDisabler* disabler; // Implementación similar a freeze/thaw pero a nivel de eventos y no respecto a responsabilidad de widgets.

//endregion


//region "login e inicializacion"
public:
	void Login();
	void MostrarVentana();

//endregion

protected:
	GNC::GUI::PanelHistorial2*  m_pHistorial;

	wxMenu*                     m_pMenuModulo;
	AUI_NAMESPACE wxAuiToolBar* m_pBarraComun;

	/*
	ssize_t                     m_NumBackgroundRunning;
	ssize_t                     m_NumBackgroundCount;
	bool                        m_Canceled;
	wxCriticalSection           m_BackgroundCriticalSection;

	ssize_t                     m_NumComandosRunning;
	ssize_t                     m_NumComandosCount;
	wxCriticalSection           m_ComandosCriticalSection;
	*/

	// Variable que controla la coherencia de confirmación entre cerrado de la aplicacion y cerrado de tabs para
	// no informar varias veces de lo mismo.
	bool                  m_TratandoDeCerrar;

	wxMenuBar*            m_pMenuBar;
	wxPrintData*	       m_pPrintData;

	DECLARE_EVENT_TABLE()
	friend class GNC::GCS::ControladorVistas;
	bool                  m_Iniciada;
};

/* Acciones de Menus */
enum {
	ID_Inicio_Aplicacion = 99
};
